pub struct QueueInfo {
pub queue_type: QueueType,
pub dedicated: bool,
pub can_present: bool,
pub family_index: u32,
pub flags: QueueFlags,
}Expand description
Stores all information of a queue that was found on the physical device.
Fields
queue_type: QueueTypeFunctionality that this queue provides.
dedicated: boolWhether this is a dedicated queue or not.
can_present: boolWhether this queue is capable of presenting to a surface.
family_index: u32The queue family index.
flags: QueueFlagsAll supported operations on this queue, instead of its primary type.