Image

Struct Image 

pub struct Image<A: Allocator = DefaultAllocator> { /* private fields */ }
Abstraction over a VkImage. Stores information about size, format, etc. Additionally couples the image data together with a memory allocation.

Implementations

Source

impl<A: Allocator> Image<A>

pub fn new( device: Device, alloc: &mut A, width: u32, height: u32, usage: ImageUsageFlags, format: Format, samples: SampleCountFlags, ) -> Result<Self>

Create a new simple [VkImage] and allocate some memory to it.

pub fn view(&self, aspect: ImageAspectFlags) -> Result<ImageView>

Construct a trivial ImageView from this Image. This is an image view that views the entire image subresource.

Lifetime

The returned ImageView is valid as long as self is valid.

pub fn is_owned(&self) -> bool

Whether this image resource is owned by the application or an external manager (such as the swapchain).

pub unsafe fn handle(&self) -> Image

Get unsafe access to the underlying VkImage handle.

Safety

Any vulkan calls that mutate this image’s state may put the system into an undefined state.

pub fn format(&self) -> Format

Get the image format

pub fn size(&self) -> Extent3D

Get the image size

pub fn width(&self) -> u32

Get the image width

pub fn height(&self) -> u32

Get the image height

pub fn depth(&self) -> u32

Get the image depth (for 2D images, this is 1)

pub fn layers(&self) -> u32

Get the number of layers in the image

pub fn mip_levels(&self) -> u32

Get the number of mip levels in the image

pub fn samples(&self) -> SampleCountFlags

Get the number of MSAA samples for this image.