pub struct Image<A: Allocator = DefaultAllocator> { /* private fields */ }Expand description
Abstraction over a VkImage. Stores information about size, format, etc. Additionally couples the image data together
with a memory allocation.
Implementations
Sourceimpl<A: Allocator> Image<A>
impl<A: Allocator> Image<A>
Sourcepub fn new(
device: Device,
alloc: &mut A,
width: u32,
height: u32,
usage: ImageUsageFlags,
format: Format,
samples: SampleCountFlags,
) -> Result<Self>
pub fn new( device: Device, alloc: &mut A, width: u32, height: u32, usage: ImageUsageFlags, format: Format, samples: SampleCountFlags, ) -> Result<Self>
Create a new simple [VkImage] and allocate some memory to it.
Sourcepub fn view(&self, aspect: ImageAspectFlags) -> Result<ImageView>
pub fn view(&self, aspect: ImageAspectFlags) -> Result<ImageView>
Sourcepub fn is_owned(&self) -> bool
pub fn is_owned(&self) -> bool
Whether this image resource is owned by the application or an external manager (such as the swapchain).
Sourcepub unsafe fn handle(&self) -> Image
pub unsafe fn handle(&self) -> Image
Get unsafe access to the underlying VkImage handle.
Safety
Any vulkan calls that mutate this image’s state may put the system into an undefined state.
Sourcepub fn mip_levels(&self) -> u32
pub fn mip_levels(&self) -> u32
Get the number of mip levels in the image
Sourcepub fn samples(&self) -> SampleCountFlags
pub fn samples(&self) -> SampleCountFlags
Get the number of MSAA samples for this image.